@@ -7,7 +7,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw( rename );
 
-our $VERSION = '1.90_5';
+our $VERSION = '1.99_9';
 
 sub import {
     my $pack = shift;
@@ -164,7 +164,7 @@ File::Rename - Perl extension for renaming multiple files
 
 =head1 DESCRIPTION
 
-=head2 USE OPTINS
+=head2 USE OPTIONS
 
 Parameters to C<use File::Rename> consists of
 functions to be imported and configuration options.
@@ -306,7 +306,8 @@ Errors from the code argument are not trapped.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004, 2005, 2006, 2011, 2018, 2021 by Robin Barker
+Copyright (C) 2004, 2005, 2006, 2011, 2018, 2021, 2022 
+by Robin Barker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.4 or,
